function ndx = gps2ndx(gps,gps0,fs)
%GPS2NDX Convert gps times to indices
%
%SYNOPSIS
%   NDX = gps2ndx(GPS, GPS0, FS)
%
%INPUT
%   GPS     gps time(s). Either a float or a struct with elements sec, ns
%   GPS0    base gps time (gps time of sample 1). Either a float or a
%       struct with elements sec, ns
%   FS      sample rate
%
%OUTPUT
%   NDX     Struct (array) of index, intersample fraction corresponding to
%       gps time(s) since gps0.
%       n: sample (immediately preceeding gps time)
%       is: intersample fraction in [0,1)
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: gps2ndx.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

if (nargin ~= 3)
  error('usage: ndx = gps2ndx(gps,gps0,fs)');
end

if (isstruct(gps))
  gps = [gps(:).sec]+[gps(:).ns]/1e9;
end
if (isstruct(gps0))
  gps0 = gps0.sec + gps0.ns/1e9;
end

ndx = (gps-gps0)*fs;
n   = floor(ndx);
is  = ndx - n;
ndx = struct('n',num2cell(n+1),'is',num2cell(is));

return
