function gpsResult = gpsavg(gpsTime1,gpsTime2)
%GPSAVG Average (time1, time2) in (S, NS) given two GSP times
%
%SYNOPSIS
%   GPSRESULT = gpsavg(GPSTIME1, GPSTIME2)
%
%INPUT
%   GPSTIME1    GPS time (struct with elements sec, ns)
%       sec: whole seconds
%       ns: residue in nano-seconds
%   GPSTIME2    GPS time to be averaged with gpsTime1
%
%OUTPUT
%   GPSRESULT   Time difference (struct with elements sec, ns)
%
% Sign convention if time < 0, .sec, .ns are both negative
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: gpsavg.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

avgSec = 0;
avgNsec = 0;
% IF # input arguments is wrong
%   CREATE error
% EXIT
error(nargchk(2,2,nargin),'struct')

% IF T1 is a GPS structure
%	GET sec, ns from structure
% ELSE
%   CONVERT time to GPS structure
%	GET sec, ns from structure
% END
% IF T2 is a GPS structure
%	GET sec, ns from structure
% ELSE
%   CONVERT time to GPS structure
%	GET sec, ns from structure
% END
if(isstruct(gpsTime1))
	t1Sec = [gpsTime1(:).sec];
	t1Nsec = [gpsTime1(:).ns];
else
	t1 = time2gps(gpsTime1);
    t1Sec = [t1(:).sec];
	t1Nsec = [t1(:).ns];
end
if(isstruct(gpsTime2))
	t2Sec = [gpsTime2(:).sec];
	t2Nsec = [gpsTime2(:).ns];
else
	t2 = time2gps(gpsTime2);
    t2Sec = [t2(:).sec];
	t2Nsec = [t2(:).ns];
end

% SET Average Sec = average of seconds of GPS time
% SET Whole Sec = Average Sec truncated to whole seconds
% SET Average NS = average of nanoseconds of GPS time
% SET Residue = Average Sec - Whole Sec
% IF Residue not = 0
%	CONVERT residue to nanoseconds
%	ADD residue (in nanoseconds) to Average NS
%   IF Average NS > 1 second
%       SET Whole Sec = Whole Sec + 1 second
%       SET Average NS = Average NS - 1 second
%   ELSEIF Average NS < -1 second
%       SET Whole Sec = Whole SEc - 1 second
%       SET Average NS = Average NS + 1 second
%   ENDIF
% END
% SET Whole NS = Average NS truncated to whole nanoseconds
% CREATE output as GPS structure
nsecPerSec = 1000000000;
avgSec = (t1Sec + t2Sec)/2.0;
wholeSec = fix(avgSec);
avgNsec = (t1Nsec + t2Nsec)/2.0;
residSec = avgSec - wholeSec;
indxR = find(residSec~=0);
residNsec = zeros(size(t1Sec));
residNsec(indxR) = residSec(indxR) * nsecPerSec;
avgNsec(indxR) = avgNsec(indxR) + residNsec(indxR);
indxG = find(avgNsec(indxR)>nsecPerSec);
indxL = find(avgNsec(indxR)<(-1*nsecPerSec));
wholeSec(indxR(indxG)) = wholeSec(indxR(indxG)) + 1;
avgNsec(indxR(indxG)) = avgNsec(indxR(indxG)) - nsecPerSec;
wholeSec(indxR(indxL)) = wholeSec(indxR(indxL)) - 1;
avgNsec(indxR(indxL)) = avgNsec(indxR(indxL)) + nsecPerSec;
wholeNsec = fix(avgNsec);
gpsResult = struct('sec',num2cell(wholeSec),'ns',num2cell(wholeNsec));

return
